/**
 * @file vga.c
 *
 * @author Spin + ASM by Chip Gracey
 * Converted from Spin + ASM with Eric Smith's Spin2Cpp utility
 *
 * @copyright
 * Copyright (C) Parallax, Inc. 2013. All Rights MIT Licensed.
 *
 * @brief VGA driver.
 */


#include <propeller.h>
#include "vgatext.h"

#ifdef __GNUC__
#define INLINE__ static inline
#define PostEffect__(X, Y) __extension__({ int32_t tmp__ = (X); (X) = (Y); tmp__; })
#else
#define INLINE__ static
static int32_t tmp__;
#define PostEffect__(X, Y) (tmp__ = (X), (X) = (Y), tmp__)
#define waitcnt(n) _waitcnt(n)
#define locknew() _locknew()
#define lockret(i) _lockret(i)
#define lockset(i) _lockset(i)
#define lockclr(i) _lockclr(i)
#define coginit(id, code, par) _coginit((unsigned)(par)>>2, (unsigned)(code)>>2, id)
#define cognew(code, par) coginit(0x8, (code), (par))
#define cogstop(i) _cogstop(i)
#endif

static vgaSpin thisobj;
static uint8_t dat[] = {
  0x4f, 0xa8, 0xfd, 0xa0, 0x08, 0xb0, 0xfd, 0xa0, 0xd4, 0xaa, 0xbd, 0x5c, 0x02, 0xb0, 0xfd, 0xe4, 
  0xe7, 0xcc, 0xbd, 0xa0, 0x00, 0xca, 0xfd, 0xa0, 0x04, 0xd8, 0x7d, 0x62, 0xf0, 0x9b, 0x3d, 0x08, 
  0x0c, 0xba, 0x7d, 0xec, 0xdd, 0xb0, 0xbd, 0xa0, 0x80, 0x85, 0xfc, 0x54, 0x3c, 0x9c, 0xfc, 0x5c, 
  0xed, 0xc2, 0xbd, 0xa0, 0xf0, 0xb2, 0xbd, 0xa0, 0xf2, 0xbe, 0xbd, 0xa0, 0x01, 0xca, 0xd5, 0x6c, 
  0x25, 0xca, 0x55, 0xec, 0x14, 0xb6, 0x7d, 0xec, 0xdb, 0xfe, 0xbf, 0xa0, 0x00, 0x00, 0x7f, 0xfc, 
  0xef, 0xb0, 0xbd, 0xa0, 0xde, 0xfe, 0xbf, 0xa0, 0xe1, 0xc4, 0xbd, 0x04, 0xce, 0xc4, 0xbd, 0x80, 
  0x06, 0xc4, 0xfd, 0x24, 0xe2, 0xc6, 0xbd, 0x08, 0x10, 0xc4, 0xfd, 0x28, 0xe2, 0x3a, 0xbc, 0x54, 
  0x02, 0xc2, 0xfd, 0x80, 0xe3, 0x00, 0x3f, 0xfc, 0x16, 0xb0, 0xfd, 0xe4, 0xe0, 0xc2, 0xbd, 0x84, 
  0x23, 0xb4, 0x7d, 0xec, 0xda, 0xfe, 0xbf, 0xa0, 0x00, 0x00, 0x7f, 0xfc, 0x01, 0xb0, 0xfd, 0xa0, 
  0x44, 0x9c, 0xfc, 0x5c, 0x0f, 0xbe, 0xfd, 0xe4, 0xd0, 0x9c, 0xbd, 0x20, 0xe4, 0x9c, 0xbd, 0x81, 
  0xd0, 0x9c, 0xbd, 0x24, 0x0e, 0x00, 0x4c, 0x5c, 0xe0, 0xc2, 0xbd, 0x80, 0x0e, 0xb2, 0xfd, 0xe5, 
  0x30, 0xb8, 0x7d, 0xec, 0xdc, 0xb0, 0xbd, 0xa0, 0x80, 0x85, 0xfc, 0x54, 0x3c, 0x9c, 0xfc, 0x5c, 
  0x01, 0xca, 0xd5, 0x6f, 0xf0, 0x99, 0x29, 0x08, 0x4f, 0xa8, 0xfd, 0xa0, 0xfa, 0xb0, 0xbd, 0xc9, 
  0x3c, 0x9c, 0xfc, 0x5c, 0xfb, 0xb0, 0xbd, 0xa0, 0x3b, 0x9c, 0xfc, 0x5c, 0xfc, 0xb0, 0xbd, 0xa0, 
  0x3b, 0x9c, 0xfc, 0x5c, 0x07, 0x00, 0x54, 0x5c, 0x04, 0x00, 0x7c, 0x5c, 0x02, 0xca, 0x7d, 0x85, 
  0xe8, 0xfe, 0xbf, 0xa0, 0xe9, 0xfe, 0x8f, 0x80, 0x01, 0xcc, 0xd1, 0x6c, 0x00, 0xcc, 0x71, 0xfc, 
  0xe9, 0xfe, 0xb3, 0xa0, 0x01, 0xcc, 0xe1, 0x6c, 0x00, 0xcc, 0x7d, 0xfc, 0xd4, 0xaa, 0x8d, 0x5c, 
  0xf6, 0xfe, 0xbf, 0xa0, 0x00, 0xcc, 0x7d, 0xfc, 0xf7, 0xfe, 0xbf, 0xa0, 0x02, 0xcc, 0xfd, 0x6c, 
  0x00, 0xcc, 0x7d, 0xfc, 0xf8, 0xfe, 0xbf, 0xa0, 0x02, 0xcc, 0xfd, 0x6c, 0x00, 0xcc, 0x7d, 0xfc, 
  0x3c, 0xb0, 0xfd, 0xe5, 0xe6, 0x84, 0xfc, 0x54, 0x00, 0x00, 0x7c, 0x5c, 0xf0, 0xad, 0xbd, 0xa0, 
  0xea, 0xa6, 0xfc, 0x54, 0x14, 0xae, 0xfd, 0xa0, 0x04, 0xac, 0xfd, 0x80, 0xd6, 0x00, 0xbc, 0x08, 
  0xca, 0xa6, 0xbc, 0x80, 0x52, 0xae, 0xfd, 0xe4, 0x02, 0xac, 0xfd, 0xa0, 0xeb, 0xac, 0xbd, 0x2c, 
  0x01, 0xac, 0xfd, 0x84, 0x20, 0xd6, 0x7d, 0x61, 0x38, 0xd6, 0xfd, 0x60, 0xeb, 0xac, 0xbd, 0x28, 
  0xd6, 0xfc, 0xbf, 0x50, 0xeb, 0xac, 0xbd, 0x2c, 0x03, 0xd6, 0xfd, 0x28, 0xeb, 0xfc, 0xbf, 0x54, 
  0xd6, 0xec, 0x8f, 0xa0, 0x00, 0xee, 0xcf, 0xa0, 0x00, 0xec, 0xf3, 0xa0, 0xd6, 0xee, 0xb3, 0xa0, 
  0xbd, 0xd4, 0x7d, 0xec, 0xd5, 0xa8, 0xbd, 0x5c, 0x00, 0xac, 0xfd, 0x08, 0x01, 0xac, 0xfd, 0x28, 
  0xc8, 0xac, 0x3d, 0x85, 0xbd, 0x00, 0x70, 0x5c, 0xc6, 0xfa, 0xbd, 0x48, 0xc7, 0xfa, 0xbd, 0x4c, 
  0x0b, 0xac, 0xfd, 0xa0, 0xfd, 0x90, 0x3d, 0x85, 0x01, 0xfa, 0xf1, 0x28, 0x01, 0xac, 0xf1, 0x80, 
  0x6d, 0x00, 0x70, 0x5c, 0xc9, 0xfa, 0x3d, 0x85, 0x01, 0xfa, 0xf1, 0x2c, 0x01, 0xb0, 0xf1, 0x84, 
  0x71, 0x00, 0x70, 0x5c, 0xd6, 0xf0, 0xbf, 0x58, 0x00, 0xac, 0xfd, 0x08, 0x21, 0xce, 0xfd, 0xa0, 
  0xd6, 0xfa, 0xbd, 0xe1, 0x01, 0xae, 0xfd, 0x34, 0x01, 0xfa, 0xfd, 0x2c, 0x78, 0xce, 0xfd, 0xe4, 
  0xd7, 0xf4, 0xbf, 0xa0, 0x01, 0xd8, 0x7d, 0x61, 0xd1, 0xce, 0xbd, 0x74, 0x02, 0xd8, 0x7d, 0x61, 
  0xd2, 0xce, 0xbd, 0x74, 0xd5, 0xa8, 0xbd, 0x5c, 0xf1, 0xbc, 0xbd, 0xa0, 0x08, 0xbc, 0xfd, 0x2c, 
  0xf1, 0xbc, 0xbd, 0x68, 0x04, 0xbc, 0xfd, 0x2c, 0xef, 0xc0, 0xbd, 0xa0, 0x01, 0xc0, 0xfd, 0x2c, 
  0xf5, 0xd0, 0xbd, 0xa0, 0xf6, 0xd2, 0xbd, 0xa4, 0xf7, 0xd2, 0xbd, 0x84, 0xf8, 0xd2, 0xbd, 0x84, 
  0xe9, 0xd0, 0xbd, 0x84, 0x01, 0xd0, 0xfd, 0x29, 0xe8, 0xd2, 0xbd, 0xc8, 0xef, 0xac, 0xbd, 0xa0, 
  0xf1, 0xae, 0xbd, 0xa0, 0xb7, 0x78, 0xfd, 0x5c, 0xf5, 0xb4, 0xbd, 0xa0, 0xd6, 0xb4, 0xbd, 0x84, 
  0x01, 0xb4, 0xfd, 0x29, 0xf3, 0xb6, 0xbd, 0xa0, 0xda, 0xb6, 0xbd, 0xc8, 0xf3, 0xb4, 0xbd, 0x84, 
  0xf0, 0xac, 0xbd, 0xa0, 0xf2, 0xae, 0xbd, 0xa0, 0xb7, 0x78, 0xfd, 0x5c, 0x08, 0xd8, 0x7d, 0x61, 
  0x01, 0xa0, 0xfd, 0x70, 0xcf, 0xc8, 0xbd, 0xa0, 0x01, 0xc8, 0xf1, 0x28, 0x01, 0xac, 0xf1, 0x2c, 
  0x04, 0xd8, 0x7d, 0x61, 0x01, 0xac, 0xf1, 0x28, 0xf9, 0xb8, 0xbd, 0xa0, 0xd6, 0xb8, 0xbd, 0x84, 
  0x01, 0xb8, 0xfd, 0x29, 0xf4, 0xba, 0xbd, 0xa4, 0xdc, 0xba, 0xbd, 0xc8, 0xf4, 0xb8, 0xbd, 0x80, 
  0x60, 0xfc, 0xff, 0x58, 0xd5, 0xa8, 0xbd, 0x5c, 0x0d, 0xac, 0xfd, 0xa0, 0xb2, 0xae, 0xbd, 0xa0, 
  0x07, 0xae, 0xfd, 0x28, 0xfc, 0xae, 0xfd, 0x60, 0xee, 0xae, 0xbd, 0x80, 0xd7, 0xae, 0xbd, 0x08, 
  0xd3, 0xae, 0xbd, 0x60, 0xe7, 0xae, 0xbd, 0x68, 0xd7, 0x00, 0xbf, 0xa0, 0xca, 0x64, 0xbd, 0x80, 
  0xcb, 0x64, 0xbd, 0x64, 0xab, 0xac, 0xfd, 0xe4, 0xa9, 0x00, 0x7c, 0x5c, 0x0b, 0xae, 0xfd, 0x2c, 
  0x08, 0xc4, 0xfd, 0xa0, 0x01, 0xac, 0xfd, 0x29, 0xd7, 0xac, 0xb1, 0x80, 0xb9, 0xc4, 0xfd, 0xe4, 
  0x00, 0x00, 0x7c, 0x5c, 0x00, 0xf0, 0xff, 0xa0, 0x00, 0xfc, 0xff, 0xa0, 0xf0, 0xe9, 0x3f, 0x08, 
  0x00, 0xac, 0xfd, 0x08, 0x08, 0xac, 0xfd, 0x28, 0x03, 0xac, 0xfd, 0x48, 0xf1, 0xad, 0xbd, 0x80, 
  0x00, 0xac, 0xfd, 0xf8, 0x00, 0x00, 0x7c, 0x5c, 0x20, 0xa1, 0x07, 0x00, 0x00, 0x20, 0xa1, 0x07, 
  0x00, 0x12, 0x7a, 0x00, 0x00, 0x09, 0x3d, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 
  0x01, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x02, 0x02, 0x02, 0x02, 0xfc, 0xfc, 0xfc, 0xfc, 
};
int32_t vgaSpin_Start(int32_t Vgaptr)
{
  int32_t Okay = 0;
  vgaSpin_Stop();
  Okay = (thisobj.Cog = (cognew((int32_t)(&(*(int32_t *)&dat[0])), Vgaptr) + 1));
  return Okay;
}

int32_t vgaSpin_Stop(void)
{
  if (thisobj.Cog) {
    cogstop((PostEffect__(thisobj.Cog, 0) - 1));
  }
  return 0;
}

/**
 * TERMS OF USE: MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */


